@@ -3,12 +3,12 @@ modelComparison <- function (X,Y,type="all",K=10,test = NULL,...) {
     if (length(type) == 1 && type == "all") {
         type <- c("Linear", "StepLinear","Additive", "PolyMARS", "MARS","Kriging")
     }
-	
+
     data <- data.frame(X, Y)
     X <- data.frame(X)
     f <- dim(X)[2]
     n <- dim(data)[1]
-	
+
     # Learning criteria
 	learningCrit 			<- data.frame(matrix(0, nrow = 2, ncol = length(type)))
     rownames(learningCrit) <- c("R2", "RMSE")
@@ -18,7 +18,7 @@ modelComparison <- function (X,Y,type="all",K=10,test = NULL,...) {
 	# Test criteria
 	testCrit <- data.frame(matrix(0, nrow = 2, ncol = length(type)))
 	rownames(testCrit) <- c("R2", "RMSE")
-	
+
     # Vrification des donnes (apprentissage et test de mme dim.)
 	if (!is.null(test)){
 		if (dim(test)[2] != dim(data)[2]) {
@@ -30,28 +30,28 @@ modelComparison <- function (X,Y,type="all",K=10,test = NULL,...) {
 	# Pour les labels besoin de connatre le nombre de modles  comparer
 	Nb_model <- data.frame(matrix(0,nrow=2,ncol=6))
 	colnames(Nb_model) <- c("Linear", "StepLinear","Additive","MARS","PolyMARS","Kriging")
-	
+
 	argList <- list(...)
 	id_fmla <- 0; id_deg <- 0; p <- 0; id_gcv <- 0
 	for (i in 1:length(type)){
 	  type_ <- type[i]
-	  switch(type_, Linear   = {Nb_model[1,1] = Nb_model[1,1]+1}, 
+	  switch(type_, Linear   = {Nb_model[1,1] = Nb_model[1,1]+1},
 					Additive = {Nb_model[1,3] = Nb_model[1,3]+1},
 					StepLinear = {Nb_model[1,2] = Nb_model[1,2]+1},
 					MARS ={Nb_model[1,4] = Nb_model[1,4]+1},
 					PolyMARS = {Nb_model[1,5] = Nb_model[1,5]+1},
 					Kriging = {Nb_model[1,6] = Nb_model[1,6]+1})
-					
+
 	  if(type_ == "Linear" | type_ == "Additive"){
 		# Rcupre la formule + vrification cvompatibilit des entres
 		# (autant de modles que de formules -- idem pour le stepwise et
 		# le krigeage)
 		if(!is.null(argList$formula)){
 			# Rcupre le nb de formules (l_fmla) en entre
-			if (class(argList$formula)=="formula"){
+			if (inherits(argList$formula, "formula")){
 				l_fmla <- 1
 			} else l_fmla <- length(argList$formula)
-			
+
 			# Rcupre la formule (fmla) et vrifie que tout est ok.
 			if(l_fmla==1){
 				fmla <- argList$formula
@@ -66,17 +66,17 @@ modelComparison <- function (X,Y,type="all",K=10,test = NULL,...) {
 			}
 		} else { # dans le cas o rien n'est indiqu ==> formules par dfaut
 			switch(type_, Linear   = {warning("[Linear model] Argument \'formula\' not found, set at \'Y~.\'")
-										fmla <- formulaLm(X,Y)}, 
+										fmla <- formulaLm(X,Y)},
 					  Additive = {  warning("[Additive model] Argument \'formula\' not found, set at \'Y~s(X1)+...+s(Xp)\'")
 									fmla <- formulaAm(X,Y)})
 		}
 		modTmp <- modelFit(X, Y, type = type_, formula = fmla)
 	  } else if (type_ == "StepLinear"){
 		if(!is.null(argList$formula)){
-			if (class(argList$formula)=="formula"){
+			if (inherits(argList$formula, "formula")){
 				l_fmla <- 1
 			} else l_fmla <- length(argList$formula)
-			
+
 			if(l_fmla==1){
 				fmla <- argList$formula
 			} else if(l_fmla>=2 & l_fmla<=length(type)){
@@ -129,7 +129,7 @@ modelComparison <- function (X,Y,type="all",K=10,test = NULL,...) {
 		} else if (type_ == "PolyMARS"){
 			if(!is.null(argList$gcv)){
 				l_gcv <- length(argList$gcv)
-				if(l_gcv == 1){ 
+				if(l_gcv == 1){
 					id_gcv <- 1
 				} else if (l_gcv >= 2 & l_gcv <= length(type)){
 					id_gcv <- id_gcv+1
@@ -147,9 +147,9 @@ modelComparison <- function (X,Y,type="all",K=10,test = NULL,...) {
 			modTmp <- modelFit(X, Y, type = type_, gcv=gcv)
 		} else if (type_ == "Kriging"){
 		  if(!is.null(argList$formula)){
-			if (class(argList$formula)=="formula"){ l_fmla <- 1
+			if (inherits(argList$formula, "formula")){ l_fmla <- 1
 			} else l_fmla <- length(argList$formula)
-			
+
 			if(l_fmla==1){	fmla <- argList$formula
 			} else if(l_fmla>=2 & l_fmla<=length(type)){
 				id_fmla <- id_fmla+1
@@ -166,7 +166,7 @@ modelComparison <- function (X,Y,type="all",K=10,test = NULL,...) {
 		  }
 		  id_covtype <- 0
 			if(!is.null(argList$covtype)){
-				if (class(argList$formula)=="vector"){ 
+				if (inherits(argList$formula, "vector")){
 					l_covtype <- length(argList$covtype)
 				} else l_covtype <- 1
 				if(l_covtype==1){
@@ -183,10 +183,10 @@ modelComparison <- function (X,Y,type="all",K=10,test = NULL,...) {
 				} else {
 					warning("[Kriging model] Argument \'covtype\'  set at \"matern5_2\"")
 							covtype="matern5_2"
-				}	
+				}
 			modTmp <- modelFit(X, Y, type = type_,formula=fmla,covtype=covtype)
 		}
-		
+
 		if(type_ == "Linear" | type_ == "StepLinear" | type_ == "Additive" | type_ == "MARS"){
 			learningCrit[1, i] <- R2(Y, modTmp$model$fitted.values)
 			learningCrit[2, i] <- RMSE(Y, modTmp$model$fitted.values)
@@ -212,14 +212,14 @@ modelComparison <- function (X,Y,type="all",K=10,test = NULL,...) {
 			testCrit[2, i] <- RMSE(test[,f+1], Ytest)
 		}
 	}
-		
+
     if (min(testCrit[1, ]) < 0) {
         warning("R2 calculated for the test data is negative.")
     }
     if (min(CVCrit[1, ]) < 0) {
         warning("R2 estimated by cross validation is negative.")
     }
-	
+
     if (!is.null(test)){
 		R2Crit <- data.frame(t(learningCrit[1, ]), t(CVCrit[1,]), t(testCrit[1, ]))
 	    colnames(R2Crit) <- c("learning", "cross-validation","test")
@@ -231,13 +231,13 @@ modelComparison <- function (X,Y,type="all",K=10,test = NULL,...) {
 	    RMSECrit <- data.frame(t(learningCrit[2, ]), t(CVCrit[2,]))
 	    colnames(RMSECrit) <- c("learning", "cross-validation")
 	}
-	
-	
+
+
 	c_names <- NULL
 	for (i in 1:length(type)){
 		type_ <- type[i]
-		
-			switch(type_, Linear 	= {val <- 1}, 
+
+			switch(type_, Linear 	= {val <- 1},
 					Additive 		= {val <- 3},
 					StepLinear		= {val <- 2},
 					MARS 			= {val <- 4},
@@ -248,13 +248,13 @@ modelComparison <- function (X,Y,type="all",K=10,test = NULL,...) {
 			c_names <- c(c_names,colnames(Nb_model)[val])
 		} else c_names <- c(c_names,paste(colnames(Nb_model)[val],Nb_model[2,val],sep=" "))
 	}
-	
+
 	colnames(learningCrit) 	<- c_names
 	colnames(CVCrit) 		<- c_names
 	colnames(testCrit) 		<- c_names
 	rownames(R2Crit) <- c_names
 	rownames(RMSECrit) <- c_names
-	
+
 #    op <- par(mfrow = c(1, 2), cex = 0.7)
     op <- par(ask=TRUE, cex = 0.7)
     dotchart(as.matrix(R2Crit), pch = 19, xlim = c(0, 1),xlab = list("Comparison of R2", cex=1.2, font=2))
@@ -268,4 +268,4 @@ modelComparison <- function (X,Y,type="all",K=10,test = NULL,...) {
 	if (is.null(test)){
         return(list(Learning = learningCrit, CV = CVCrit))
     } else return(list(Learning = learningCrit, CV = CVCrit, Test = testCrit))
-}
\ No newline at end of file
+}
