@@ -10,7 +10,7 @@ modelPredict <- function(model,newdata){
 	if (type=="Linear" | type == "MARS" | type == "Additive" | type == "StepLinear"){
 		y_pred <- predict(object=model$model,newdata=newdata)
 	} else if (type=="PolyMARS"){
-		y_pred <- predict.polymars(model$model,x=newdata)
+		y_pred <- polspline::predict.polymars(model$model,x=newdata)
 	} else if (type=="Kriging"){
 		y_pred <- predict(model$model,newdata,"UK")$mean
 	} else stop("This method is not implemented yet.")
